@@ -4,9 +4,9 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_18.meta_v1 import LabelSelector
-from kuber.v1_18.meta_v1 import ListMeta
-from kuber.v1_18.meta_v1 import ObjectMeta
+from kuber.v1_12.meta_v1 import LabelSelector
+from kuber.v1_12.meta_v1 import ListMeta
+from kuber.v1_12.meta_v1 import ObjectMeta
 
 
 class AggregationRule(_kuber_definitions.Definition):
@@ -72,9 +72,7 @@ class ClusterRole(_kuber_definitions.Resource):
     """
     ClusterRole is a cluster level, logical grouping of
     PolicyRules that can be referenced as a unit by a
-    RoleBinding or ClusterRoleBinding. Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 ClusterRole, and will
-    no longer be served in v1.20.
+    RoleBinding or ClusterRoleBinding.
     """
 
     def __init__(
@@ -298,9 +296,7 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
     """
     ClusterRoleBinding references a ClusterRole, but not contain
     it.  It can reference a ClusterRole in the global namespace,
-    and adds who information via Subject. Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 ClusterRoleBinding,
-    and will no longer be served in v1.20.
+    and adds who information via Subject.
     """
 
     def __init__(
@@ -523,9 +519,7 @@ class ClusterRoleBinding(_kuber_definitions.Resource):
 class ClusterRoleBindingList(_kuber_definitions.Collection):
     """
     ClusterRoleBindingList is a collection of
-    ClusterRoleBindings. Deprecated in v1.17 in favor of
-    rbac.authorization.k8s.io/v1 ClusterRoleBindingList, and
-    will no longer be served in v1.20.
+    ClusterRoleBindings
     """
 
     def __init__(
@@ -611,9 +605,7 @@ class ClusterRoleBindingList(_kuber_definitions.Collection):
 
 class ClusterRoleList(_kuber_definitions.Collection):
     """
-    ClusterRoleList is a collection of ClusterRoles. Deprecated
-    in v1.17 in favor of rbac.authorization.k8s.io/v1
-    ClusterRoles, and will no longer be served in v1.20.
+    ClusterRoleList is a collection of ClusterRoles
     """
 
     def __init__(
@@ -846,9 +838,7 @@ class PolicyRule(_kuber_definitions.Definition):
 class Role(_kuber_definitions.Resource):
     """
     Role is a namespaced, logical grouping of PolicyRules that
-    can be referenced as a unit by a RoleBinding. Deprecated in
-    v1.17 in favor of rbac.authorization.k8s.io/v1 Role, and
-    will no longer be served in v1.20.
+    can be referenced as a unit by a RoleBinding.
     """
 
     def __init__(
@@ -1050,9 +1040,7 @@ class RoleBinding(_kuber_definitions.Resource):
     in the global namespace. It adds who information via
     Subjects and namespace information by which namespace it
     exists in.  RoleBindings in a given namespace only have
-    effect in that namespace. Deprecated in v1.17 in favor of
-    rbac.authorization.k8s.io/v1 RoleBinding, and will no longer
-    be served in v1.20.
+    effect in that namespace.
     """
 
     def __init__(
@@ -1274,9 +1262,7 @@ class RoleBinding(_kuber_definitions.Resource):
 
 class RoleBindingList(_kuber_definitions.Collection):
     """
-    RoleBindingList is a collection of RoleBindings Deprecated
-    in v1.17 in favor of rbac.authorization.k8s.io/v1
-    RoleBindingList, and will no longer be served in v1.20.
+    RoleBindingList is a collection of RoleBindings
     """
 
     def __init__(
@@ -1362,9 +1348,7 @@ class RoleBindingList(_kuber_definitions.Collection):
 
 class RoleList(_kuber_definitions.Collection):
     """
-    RoleList is a collection of Roles Deprecated in v1.17 in
-    favor of rbac.authorization.k8s.io/v1 RoleList, and will no
-    longer be served in v1.20.
+    RoleList is a collection of Roles
     """
 
     def __init__(
