@@ -5,10 +5,10 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_14.meta_v1 import ListMeta
-from kuber.v1_14.meta_v1 import ObjectMeta
-from kuber.v1_14.meta_v1 import Status
-from kuber.v1_14.meta_v1 import StatusDetails
+from kuber.v1_13.meta_v1 import ListMeta
+from kuber.v1_13.meta_v1 import ObjectMeta
+from kuber.v1_13.meta_v1 import Status
+from kuber.v1_13.meta_v1 import StatusDetails
 
 
 class CustomResourceColumnDefinition(_kuber_definitions.Definition):
@@ -171,7 +171,6 @@ class CustomResourceConversion(_kuber_definitions.Definition):
 
     def __init__(
             self,
-            conversion_review_versions: typing.List[str] = None,
             strategy: str = None,
             webhook_client_config: 'WebhookClientConfig' = None,
     ):
@@ -181,46 +180,16 @@ class CustomResourceConversion(_kuber_definitions.Definition):
             kind='CustomResourceConversion'
         )
         self._properties = {
-            'conversionReviewVersions': conversion_review_versions if conversion_review_versions is not None else [],
             'strategy': strategy if strategy is not None else '',
             'webhookClientConfig': webhook_client_config if webhook_client_config is not None else WebhookClientConfig(),
 
         }
         self._types = {
-            'conversionReviewVersions': (list, str),
             'strategy': (str, None),
             'webhookClientConfig': (WebhookClientConfig, None),
 
         }
 
-    @property
-    def conversion_review_versions(self) -> typing.List[str]:
-        """
-        ConversionReviewVersions is an ordered list of preferred
-        `ConversionReview` versions the Webhook expects. API server
-        will try to use first version in the list which it supports.
-        If none of the versions specified in this list supported by
-        API server, conversion will fail for this object. If a
-        persisted Webhook configuration specifies allowed versions
-        and does not include any versions known to the API Server,
-        calls to the webhook will fail. Default to `['v1beta1']`.
-        """
-        return self._properties.get('conversionReviewVersions')
-
-    @conversion_review_versions.setter
-    def conversion_review_versions(self, value: typing.List[str]):
-        """
-        ConversionReviewVersions is an ordered list of preferred
-        `ConversionReview` versions the Webhook expects. API server
-        will try to use first version in the list which it supports.
-        If none of the versions specified in this list supported by
-        API server, conversion will fail for this object. If a
-        persisted Webhook configuration specifies allowed versions
-        and does not include any versions known to the API Server,
-        calls to the webhook will fail. Default to `['v1beta1']`.
-        """
-        self._properties['conversionReviewVersions'] = value
-
     @property
     def strategy(self) -> str:
         """
@@ -1837,7 +1806,6 @@ class JSONSchemaProps(_kuber_definitions.Definition):
             minimum: float = None,
             multiple_of: float = None,
             not_: typing.Optional['JSONSchemaProps'] = None,
-            nullable: bool = None,
             one_of: typing.List['JSONSchemaProps'] = None,
             pattern: str = None,
             pattern_properties: dict = None,
@@ -1879,7 +1847,6 @@ class JSONSchemaProps(_kuber_definitions.Definition):
             'minimum': minimum if minimum is not None else None,
             'multipleOf': multiple_of if multiple_of is not None else None,
             'not': not_ if not_ is not None else None,
-            'nullable': nullable if nullable is not None else None,
             'oneOf': one_of if one_of is not None else [],
             'pattern': pattern if pattern is not None else '',
             'patternProperties': pattern_properties if pattern_properties is not None else {},
@@ -1917,7 +1884,6 @@ class JSONSchemaProps(_kuber_definitions.Definition):
             'minimum': (float, None),
             'multipleOf': (float, None),
             'not': (JSONSchemaProps, None),
-            'nullable': (bool, None),
             'oneOf': (list, JSONSchemaProps),
             'pattern': (str, None),
             'patternProperties': (dict, None),
@@ -2331,20 +2297,6 @@ class JSONSchemaProps(_kuber_definitions.Definition):
             value = JSONSchemaProps().from_dict(value)
         self._properties['not'] = value
 
-    @property
-    def nullable(self) -> bool:
-        """
-
-        """
-        return self._properties.get('nullable')
-
-    @nullable.setter
-    def nullable(self, value: bool):
-        """
-
-        """
-        self._properties['nullable'] = value
-
     @property
     def one_of(self) -> typing.List['JSONSchemaProps']:
         """
