@@ -4,14 +4,12 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_17.meta_v1 import ListMeta
-from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_13.meta_v1 import ListMeta
+from kuber.v1_13.meta_v1 import ObjectMeta
 
 
 class PriorityClass(_kuber_definitions.Resource):
     """
-    DEPRECATED - This group version of PriorityClass is
-    deprecated by scheduling.k8s.io/v1/PriorityClass.
     PriorityClass defines mapping from a priority class name to
     the priority integer value. The value can be any valid
     integer.
@@ -22,7 +20,6 @@ class PriorityClass(_kuber_definitions.Resource):
             description: str = None,
             global_default: bool = None,
             metadata: 'ObjectMeta' = None,
-            preemption_policy: str = None,
             value: int = None,
     ):
         """Create PriorityClass instance."""
@@ -34,7 +31,6 @@ class PriorityClass(_kuber_definitions.Resource):
             'description': description if description is not None else '',
             'globalDefault': global_default if global_default is not None else None,
             'metadata': metadata if metadata is not None else ObjectMeta(),
-            'preemptionPolicy': preemption_policy if preemption_policy is not None else '',
             'value': value if value is not None else None,
 
         }
@@ -44,7 +40,6 @@ class PriorityClass(_kuber_definitions.Resource):
             'globalDefault': (bool, None),
             'kind': (str, None),
             'metadata': (ObjectMeta, None),
-            'preemptionPolicy': (str, None),
             'value': (int, None),
 
         }
@@ -95,8 +90,8 @@ class PriorityClass(_kuber_definitions.Resource):
     def metadata(self) -> 'ObjectMeta':
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -104,35 +99,13 @@ class PriorityClass(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union['ObjectMeta', dict]):
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
         self._properties['metadata'] = value
 
-    @property
-    def preemption_policy(self) -> str:
-        """
-        PreemptionPolicy is the Policy for preempting pods with
-        lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is alpha-level
-        and is only honored by servers that enable the
-        NonPreemptingPriority feature.
-        """
-        return self._properties.get('preemptionPolicy')
-
-    @preemption_policy.setter
-    def preemption_policy(self, value: str):
-        """
-        PreemptionPolicy is the Policy for preempting pods with
-        lower priority. One of Never, PreemptLowerPriority. Defaults
-        to PreemptLowerPriority if unset. This field is alpha-level
-        and is only honored by servers that enable the
-        NonPreemptingPriority feature.
-        """
-        self._properties['preemptionPolicy'] = value
-
     @property
     def value(self) -> int:
         """
@@ -336,8 +309,8 @@ class PriorityClassList(_kuber_definitions.Collection):
     def metadata(self) -> 'ListMeta':
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -345,8 +318,8 @@ class PriorityClassList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union['ListMeta', dict]):
         """
         Standard list metadata More info:
-        https://git.k8s.io/community/contributors/devel/sig-
-        architecture/api-conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/api-
+        conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ListMeta().from_dict(value)
