@@ -5,22 +5,22 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_12.core_v1 import Container
-from kuber.v1_12.core_v1 import ContainerPort
-from kuber.v1_12.core_v1 import EnvFromSource
-from kuber.v1_12.core_v1 import EnvVar
-from kuber.v1_12.batch_v1 import JobSpec
-from kuber.v1_12.core_v1 import Lifecycle
-from kuber.v1_12.meta_v1 import ListMeta
-from kuber.v1_12.meta_v1 import ObjectMeta
-from kuber.v1_12.core_v1 import ObjectReference
-from kuber.v1_12.core_v1 import Probe
-from kuber.v1_12.core_v1 import ResourceRequirements
-from kuber.v1_12.core_v1 import SecurityContext
-from kuber.v1_12.meta_v1 import Status
-from kuber.v1_12.meta_v1 import StatusDetails
-from kuber.v1_12.core_v1 import VolumeDevice
-from kuber.v1_12.core_v1 import VolumeMount
+from kuber.v1_15.core_v1 import Container
+from kuber.v1_15.core_v1 import ContainerPort
+from kuber.v1_15.core_v1 import EnvFromSource
+from kuber.v1_15.core_v1 import EnvVar
+from kuber.v1_15.batch_v1 import JobSpec
+from kuber.v1_15.core_v1 import Lifecycle
+from kuber.v1_15.meta_v1 import ListMeta
+from kuber.v1_15.meta_v1 import ObjectMeta
+from kuber.v1_15.core_v1 import ObjectReference
+from kuber.v1_15.core_v1 import Probe
+from kuber.v1_15.core_v1 import ResourceRequirements
+from kuber.v1_15.core_v1 import SecurityContext
+from kuber.v1_15.meta_v1 import Status
+from kuber.v1_15.meta_v1 import StatusDetails
+from kuber.v1_15.core_v1 import VolumeDevice
+from kuber.v1_15.core_v1 import VolumeMount
 
 
 class CronJob(_kuber_definitions.Resource):
@@ -164,7 +164,7 @@ class CronJob(_kuber_definitions.Resource):
             'volume_mounts': volume_mounts,
             'working_dir': working_dir,
         }
-        self.spec.jobTemplate.spec.template.spec.containers.append(Container(**{
+        self.spec.job_template.spec.template.spec.containers.append(Container(**{
             k: v
             for k, v in values.items()
             if v != _kuber_definitions.UNCHANGED_VALUE
@@ -177,14 +177,14 @@ class CronJob(_kuber_definitions.Resource):
         container definition exists. Return None if no container definition
         by that name exists.
         """
-        return next((c for c in self.spec.jobTemplate.spec.template.spec.containers if c.name == name), None)
+        return next((c for c in self.spec.job_template.spec.template.spec.containers if c.name == name), None)
 
     def get_containers(self) -> typing.List['Container']:
         """
         Returns the list of containers stored in this resource if any such
         containers exist.
         """
-        return self.spec.jobTemplate.spec.template.spec.containers
+        return self.spec.job_template.spec.template.spec.containers
 
     def create_resource(
             self,
@@ -670,7 +670,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             'volume_mounts': volume_mounts,
             'working_dir': working_dir,
         }
-        self.jobTemplate.spec.template.spec.containers.append(Container(**{
+        self.job_template.spec.template.spec.containers.append(Container(**{
             k: v
             for k, v in values.items()
             if v != _kuber_definitions.UNCHANGED_VALUE
@@ -683,14 +683,14 @@ class CronJobSpec(_kuber_definitions.Definition):
         container definition exists. Return None if no container definition
         by that name exists.
         """
-        return next((c for c in self.jobTemplate.spec.template.spec.containers if c.name == name), None)
+        return next((c for c in self.job_template.spec.template.spec.containers if c.name == name), None)
 
     def get_containers(self) -> typing.List['Container']:
         """
         Returns the list of containers stored in this resource if any such
         containers exist.
         """
-        return self.jobTemplate.spec.template.spec.containers
+        return self.job_template.spec.template.spec.containers
 
     def __enter__(self) -> 'CronJobSpec':
         return self
