@@ -5,11 +5,11 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_13.meta_v1 import LabelSelector
-from kuber.v1_13.meta_v1 import ListMeta
-from kuber.v1_13.meta_v1 import ObjectMeta
-from kuber.v1_13.meta_v1 import Status
-from kuber.v1_13.meta_v1 import StatusDetails
+from kuber.v1_16.meta_v1 import LabelSelector
+from kuber.v1_16.meta_v1 import ListMeta
+from kuber.v1_16.meta_v1 import ObjectMeta
+from kuber.v1_16.meta_v1 import Status
+from kuber.v1_16.meta_v1 import StatusDetails
 
 
 class CrossVersionObjectReference(_kuber_definitions.Definition):
@@ -60,8 +60,8 @@ class CrossVersionObjectReference(_kuber_definitions.Definition):
     def kind(self) -> str:
         """
         Kind of the referent; More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#types-kinds"
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#types-kinds"
         """
         return self._properties.get('kind')
 
@@ -69,8 +69,8 @@ class CrossVersionObjectReference(_kuber_definitions.Definition):
     def kind(self, value: str):
         """
         Kind of the referent; More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#types-kinds"
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#types-kinds"
         """
         self._properties['kind'] = value
 
@@ -269,8 +269,8 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
     def metadata(self) -> 'ObjectMeta':
         """
         metadata is the standard object metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -278,8 +278,8 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union['ObjectMeta', dict]):
         """
         metadata is the standard object metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
@@ -290,8 +290,8 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         """
         spec is the specification for the behaviour of the
         autoscaler. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status.
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status.
         """
         return self._properties.get('spec')
 
@@ -300,8 +300,8 @@ class HorizontalPodAutoscaler(_kuber_definitions.Resource):
         """
         spec is the specification for the behaviour of the
         autoscaler. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status.
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status.
         """
         if isinstance(value, dict):
             value = HorizontalPodAutoscalerSpec().from_dict(value)
@@ -805,7 +805,11 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
     def min_replicas(self) -> int:
         """
         minReplicas is the lower limit for the number of replicas to
-        which the autoscaler can scale down. It defaults to 1 pod.
+        which the autoscaler can scale down.  It defaults to 1 pod.
+        minReplicas is allowed to be 0 if the alpha feature gate
+        HPAScaleToZero is enabled and at least one Object or
+        External metric is configured.  Scaling is active as long as
+        at least one metric value is available.
         """
         return self._properties.get('minReplicas')
 
@@ -813,7 +817,11 @@ class HorizontalPodAutoscalerSpec(_kuber_definitions.Definition):
     def min_replicas(self, value: int):
         """
         minReplicas is the lower limit for the number of replicas to
-        which the autoscaler can scale down. It defaults to 1 pod.
+        which the autoscaler can scale down.  It defaults to 1 pod.
+        minReplicas is allowed to be 0 if the alpha feature gate
+        HPAScaleToZero is enabled and at least one Object or
+        External metric is configured.  Scaling is active as long as
+        at least one metric value is available.
         """
         self._properties['minReplicas'] = value
 
