@@ -5,10 +5,10 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_12.meta_v1 import ListMeta
-from kuber.v1_12.meta_v1 import ObjectMeta
-from kuber.v1_12.meta_v1 import Status
-from kuber.v1_12.meta_v1 import StatusDetails
+from kuber.v1_17.meta_v1 import ListMeta
+from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_17.meta_v1 import Status
+from kuber.v1_17.meta_v1 import StatusDetails
 
 
 class APIService(_kuber_definitions.Resource):
@@ -271,7 +271,8 @@ class APIService(_kuber_definitions.Resource):
 
 class APIServiceCondition(_kuber_definitions.Definition):
     """
-
+    APIServiceCondition describes the state of an APIService at
+    a particular point
     """
 
     def __init__(
@@ -529,7 +530,8 @@ class APIServiceSpec(_kuber_definitions.Definition):
     def ca_bundle(self) -> str:
         """
         CABundle is a PEM encoded CA bundle which will be used to
-        validate an API server's serving certificate.
+        validate an API server's serving certificate. If
+        unspecified, system trust roots on the apiserver are used.
         """
         return self._properties.get('caBundle')
 
@@ -537,7 +539,8 @@ class APIServiceSpec(_kuber_definitions.Definition):
     def ca_bundle(self, value: str):
         """
         CABundle is a PEM encoded CA bundle which will be used to
-        validate an API server's serving certificate.
+        validate an API server's serving certificate. If
+        unspecified, system trust roots on the apiserver are used.
         """
         self._properties['caBundle'] = value
 
@@ -764,6 +767,7 @@ class ServiceReference(_kuber_definitions.Definition):
             self,
             name: str = None,
             namespace: str = None,
+            port: int = None,
     ):
         """Create ServiceReference instance."""
         super(ServiceReference, self).__init__(
@@ -773,11 +777,13 @@ class ServiceReference(_kuber_definitions.Definition):
         self._properties = {
             'name': name if name is not None else '',
             'namespace': namespace if namespace is not None else '',
+            'port': port if port is not None else None,
 
         }
         self._types = {
             'name': (str, None),
             'namespace': (str, None),
+            'port': (int, None),
 
         }
 
@@ -809,6 +815,24 @@ class ServiceReference(_kuber_definitions.Definition):
         """
         self._properties['namespace'] = value
 
+    @property
+    def port(self) -> int:
+        """
+        If specified, the port on the service that hosting webhook.
+        Default to 443 for backward compatibility. `port` should be
+        a valid port number (1-65535, inclusive).
+        """
+        return self._properties.get('port')
+
+    @port.setter
+    def port(self, value: int):
+        """
+        If specified, the port on the service that hosting webhook.
+        Default to 443 for backward compatibility. `port` should be
+        a valid port number (1-65535, inclusive).
+        """
+        self._properties['port'] = value
+
     def __enter__(self) -> 'ServiceReference':
         return self
 
