@@ -4,9 +4,9 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_18.meta_v1 import ListMeta
-from kuber.v1_18.meta_v1 import ObjectMeta
-from kuber.v1_18.core_v1 import ObjectReference
+from kuber.v1_17.meta_v1 import ListMeta
+from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_17.core_v1 import ObjectReference
 
 
 class Endpoint(_kuber_definitions.Definition):
@@ -274,8 +274,8 @@ class EndpointPort(_kuber_definitions.Definition):
         standard Kubernetes label syntax. Un-prefixed names are
         reserved for IANA standard service names (as per RFC-6335
         and http://www.iana.org/assignments/service-names). Non-
-        standard protocols should use prefixed names such as
-        mycompany.com/my-custom-protocol.
+        standard protocols should use prefixed names. Default is
+        empty string.
         """
         return self._properties.get('appProtocol')
 
@@ -286,8 +286,8 @@ class EndpointPort(_kuber_definitions.Definition):
         standard Kubernetes label syntax. Un-prefixed names are
         reserved for IANA standard service names (as per RFC-6335
         and http://www.iana.org/assignments/service-names). Non-
-        standard protocols should use prefixed names such as
-        mycompany.com/my-custom-protocol.
+        standard protocols should use prefixed names. Default is
+        empty string.
         """
         self._properties['appProtocol'] = value
 
