@@ -5,11 +5,11 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_20.core_v1 import EventSource
-from kuber.v1_20.meta_v1 import ListMeta
-from kuber.v1_20.meta_v1 import MicroTime
-from kuber.v1_20.meta_v1 import ObjectMeta
-from kuber.v1_20.core_v1 import ObjectReference
+from kuber.v1_17.core_v1 import EventSource
+from kuber.v1_17.meta_v1 import ListMeta
+from kuber.v1_17.meta_v1 import MicroTime
+from kuber.v1_17.meta_v1 import ObjectMeta
+from kuber.v1_17.core_v1 import ObjectReference
 
 
 class Event(_kuber_definitions.Resource):
@@ -83,42 +83,40 @@ class Event(_kuber_definitions.Resource):
     @property
     def action(self) -> str:
         """
-        action is what action was taken/failed regarding to the
-        regarding object. It is machine-readable. This field can
-        have at most 128 characters.
+        What action was taken/failed regarding to the regarding
+        object.
         """
         return self._properties.get('action')
 
     @action.setter
     def action(self, value: str):
         """
-        action is what action was taken/failed regarding to the
-        regarding object. It is machine-readable. This field can
-        have at most 128 characters.
+        What action was taken/failed regarding to the regarding
+        object.
         """
         self._properties['action'] = value
 
     @property
     def deprecated_count(self) -> int:
         """
-        deprecatedCount is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return self._properties.get('deprecatedCount')
 
     @deprecated_count.setter
     def deprecated_count(self, value: int):
         """
-        deprecatedCount is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         self._properties['deprecatedCount'] = value
 
     @property
     def deprecated_first_timestamp(self) -> str:
         """
-        deprecatedFirstTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return self._properties.get('deprecatedFirstTimestamp')
 
@@ -128,8 +126,8 @@ class Event(_kuber_definitions.Resource):
             value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        deprecatedFirstTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime('%Y-%m-%dT%H:%M:%SZ')
@@ -140,8 +138,8 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_last_timestamp(self) -> str:
         """
-        deprecatedLastTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return self._properties.get('deprecatedLastTimestamp')
 
@@ -151,8 +149,8 @@ class Event(_kuber_definitions.Resource):
             value: typing.Union[str, _datetime.datetime, _datetime.date]
     ):
         """
-        deprecatedLastTimestamp is the deprecated field assuring
-        backward compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, _datetime.datetime):
             value = value.strftime('%Y-%m-%dT%H:%M:%SZ')
@@ -163,16 +161,16 @@ class Event(_kuber_definitions.Resource):
     @property
     def deprecated_source(self) -> 'EventSource':
         """
-        deprecatedSource is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         return self._properties.get('deprecatedSource')
 
     @deprecated_source.setter
     def deprecated_source(self, value: typing.Union['EventSource', dict]):
         """
-        deprecatedSource is the deprecated field assuring backward
-        compatibility with core.v1 Event type.
+        Deprecated field assuring backward compatibility with
+        core.v1 Event type
         """
         if isinstance(value, dict):
             value = EventSource().from_dict(value)
@@ -181,16 +179,14 @@ class Event(_kuber_definitions.Resource):
     @property
     def event_time(self) -> 'MicroTime':
         """
-        eventTime is the time when this Event was first observed. It
-        is required.
+        Required. Time when this Event was first observed.
         """
         return self._properties.get('eventTime')
 
     @event_time.setter
     def event_time(self, value: typing.Union['MicroTime', dict]):
         """
-        eventTime is the time when this Event was first observed. It
-        is required.
+        Required. Time when this Event was first observed.
         """
         if isinstance(value, dict):
             value = MicroTime().from_dict(value)
@@ -215,7 +211,7 @@ class Event(_kuber_definitions.Resource):
     @property
     def note(self) -> str:
         """
-        note is a human-readable description of the status of this
+        Optional. A human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -224,7 +220,7 @@ class Event(_kuber_definitions.Resource):
     @note.setter
     def note(self, value: str):
         """
-        note is a human-readable description of the status of this
+        Optional. A human-readable description of the status of this
         operation. Maximal length of the note is 1kB, but libraries
         should be prepared to handle values up to 64kB.
         """
@@ -233,38 +229,34 @@ class Event(_kuber_definitions.Resource):
     @property
     def reason(self) -> str:
         """
-        reason is why the action was taken. It is human-readable.
-        This field can have at most 128 characters.
+        Why the action was taken.
         """
         return self._properties.get('reason')
 
     @reason.setter
     def reason(self, value: str):
         """
-        reason is why the action was taken. It is human-readable.
-        This field can have at most 128 characters.
+        Why the action was taken.
         """
         self._properties['reason'] = value
 
     @property
     def regarding(self) -> 'ObjectReference':
         """
-        regarding contains the object this Event is about. In most
-        cases it's an Object reporting controller implements, e.g.
-        ReplicaSetController implements ReplicaSets and this event
-        is emitted because it acts on some changes in a ReplicaSet
-        object.
+        The object this Event is about. In most cases it's an Object
+        reporting controller implements. E.g. ReplicaSetController
+        implements ReplicaSets and this event is emitted because it
+        acts on some changes in a ReplicaSet object.
         """
         return self._properties.get('regarding')
 
     @regarding.setter
     def regarding(self, value: typing.Union['ObjectReference', dict]):
         """
-        regarding contains the object this Event is about. In most
-        cases it's an Object reporting controller implements, e.g.
-        ReplicaSetController implements ReplicaSets and this event
-        is emitted because it acts on some changes in a ReplicaSet
-        object.
+        The object this Event is about. In most cases it's an Object
+        reporting controller implements. E.g. ReplicaSetController
+        implements ReplicaSets and this event is emitted because it
+        acts on some changes in a ReplicaSet object.
         """
         if isinstance(value, dict):
             value = ObjectReference().from_dict(value)
@@ -273,18 +265,18 @@ class Event(_kuber_definitions.Resource):
     @property
     def related(self) -> 'ObjectReference':
         """
-        related is the optional secondary object for more complex
-        actions. E.g. when regarding object triggers a creation or
-        deletion of related object.
+        Optional secondary object for more complex actions. E.g.
+        when regarding object triggers a creation or deletion of
+        related object.
         """
         return self._properties.get('related')
 
     @related.setter
     def related(self, value: typing.Union['ObjectReference', dict]):
         """
-        related is the optional secondary object for more complex
-        actions. E.g. when regarding object triggers a creation or
-        deletion of related object.
+        Optional secondary object for more complex actions. E.g.
+        when regarding object triggers a creation or deletion of
+        related object.
         """
         if isinstance(value, dict):
             value = ObjectReference().from_dict(value)
@@ -293,52 +285,46 @@ class Event(_kuber_definitions.Resource):
     @property
     def reporting_controller(self) -> str:
         """
-        reportingController is the name of the controller that
-        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
-        cannot be empty for new Events.
+        Name of the controller that emitted this Event, e.g.
+        `kubernetes.io/kubelet`.
         """
         return self._properties.get('reportingController')
 
     @reporting_controller.setter
     def reporting_controller(self, value: str):
         """
-        reportingController is the name of the controller that
-        emitted this Event, e.g. `kubernetes.io/kubelet`. This field
-        cannot be empty for new Events.
+        Name of the controller that emitted this Event, e.g.
+        `kubernetes.io/kubelet`.
         """
         self._properties['reportingController'] = value
 
     @property
     def reporting_instance(self) -> str:
         """
-        reportingInstance is the ID of the controller instance, e.g.
-        `kubelet-xyzf`. This field cannot be empty for new Events
-        and it can have at most 128 characters.
+        ID of the controller instance, e.g. `kubelet-xyzf`.
         """
         return self._properties.get('reportingInstance')
 
     @reporting_instance.setter
     def reporting_instance(self, value: str):
         """
-        reportingInstance is the ID of the controller instance, e.g.
-        `kubelet-xyzf`. This field cannot be empty for new Events
-        and it can have at most 128 characters.
+        ID of the controller instance, e.g. `kubelet-xyzf`.
         """
         self._properties['reportingInstance'] = value
 
     @property
     def series(self) -> 'EventSeries':
         """
-        series is data about the Event series this event represents
-        or nil if it's a singleton Event.
+        Data about the Event series this event represents or nil if
+        it's a singleton Event.
         """
         return self._properties.get('series')
 
     @series.setter
     def series(self, value: typing.Union['EventSeries', dict]):
         """
-        series is data about the Event series this event represents
-        or nil if it's a singleton Event.
+        Data about the Event series this event represents or nil if
+        it's a singleton Event.
         """
         if isinstance(value, dict):
             value = EventSeries().from_dict(value)
@@ -347,16 +333,16 @@ class Event(_kuber_definitions.Resource):
     @property
     def type_(self) -> str:
         """
-        type is the type of this event (Normal, Warning), new types
-        could be added in the future. It is machine-readable.
+        Type of this event (Normal, Warning), new types could be
+        added in the future.
         """
         return self._properties.get('type')
 
     @type_.setter
     def type_(self, value: str):
         """
-        type is the type of this event (Normal, Warning), new types
-        could be added in the future. It is machine-readable.
+        Type of this event (Normal, Warning), new types could be
+        added in the future.
         """
         self._properties['type'] = value
 
@@ -522,7 +508,7 @@ class EventList(_kuber_definitions.Collection):
     @property
     def items(self) -> typing.List['Event']:
         """
-        items is a list of schema objects.
+        Items is a list of schema objects.
         """
         return self._properties.get('items')
 
@@ -532,7 +518,7 @@ class EventList(_kuber_definitions.Collection):
             value: typing.Union[typing.List['Event'], typing.List[dict]]
     ):
         """
-        items is a list of schema objects.
+        Items is a list of schema objects.
         """
         cleaned = []
         for item in value:
@@ -591,6 +577,7 @@ class EventSeries(_kuber_definitions.Definition):
             self,
             count: int = None,
             last_observed_time: 'MicroTime' = None,
+            state: str = None,
     ):
         """Create EventSeries instance."""
         super(EventSeries, self).__init__(
@@ -600,48 +587,66 @@ class EventSeries(_kuber_definitions.Definition):
         self._properties = {
             'count': count if count is not None else None,
             'lastObservedTime': last_observed_time if last_observed_time is not None else MicroTime(),
+            'state': state if state is not None else '',
 
         }
         self._types = {
             'count': (int, None),
             'lastObservedTime': (MicroTime, None),
+            'state': (str, None),
 
         }
 
     @property
     def count(self) -> int:
         """
-        count is the number of occurrences in this series up to the
-        last heartbeat time.
+        Number of occurrences in this series up to the last
+        heartbeat time
         """
         return self._properties.get('count')
 
     @count.setter
     def count(self, value: int):
         """
-        count is the number of occurrences in this series up to the
-        last heartbeat time.
+        Number of occurrences in this series up to the last
+        heartbeat time
         """
         self._properties['count'] = value
 
     @property
     def last_observed_time(self) -> 'MicroTime':
         """
-        lastObservedTime is the time when last Event from the series
-        was seen before last heartbeat.
+        Time when last Event from the series was seen before last
+        heartbeat.
         """
         return self._properties.get('lastObservedTime')
 
     @last_observed_time.setter
     def last_observed_time(self, value: typing.Union['MicroTime', dict]):
         """
-        lastObservedTime is the time when last Event from the series
-        was seen before last heartbeat.
+        Time when last Event from the series was seen before last
+        heartbeat.
         """
         if isinstance(value, dict):
             value = MicroTime().from_dict(value)
         self._properties['lastObservedTime'] = value
 
+    @property
+    def state(self) -> str:
+        """
+        Information whether this series is ongoing or finished.
+        Deprecated. Planned removal for 1.18
+        """
+        return self._properties.get('state')
+
+    @state.setter
+    def state(self, value: str):
+        """
+        Information whether this series is ongoing or finished.
+        Deprecated. Planned removal for 1.18
+        """
+        self._properties['state'] = value
+
     def __enter__(self) -> 'EventSeries':
         return self
 
