@@ -6,13 +6,13 @@ from kuber import versioning
 # package and kuber metadata around its creation and labeling within the
 # kuber library.
 KUBERNETES_VERSION = versioning.KubernetesVersion(
-    label='v1.12',
-    version='v1.12.10',
+    label='v1.19',
+    version='v1.19.0-rc.2',
     major='1',
-    minor='12',
-    patch='10',
-    pre_release='',
+    minor='19',
+    patch='0',
+    pre_release='rc.2',
     build='',
-    created_at=_datetime.datetime(2020, 7, 15),
-    commit_sha='e3c134023df5dea457638b614ee17ef234dc34a6'
+    created_at=_datetime.datetime(2020, 7, 24),
+    commit_sha='27bb2a4a0a5cb8330178d19e57fa61fffa895c98'
 )
