@@ -5,22 +5,22 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_11.core_v1 import Container
-from kuber.v1_11.core_v1 import ContainerPort
-from kuber.v1_11.core_v1 import EnvFromSource
-from kuber.v1_11.core_v1 import EnvVar
-from kuber.v1_11.batch_v1 import JobSpec
-from kuber.v1_11.core_v1 import Lifecycle
-from kuber.v1_11.meta_v1 import ListMeta
-from kuber.v1_11.meta_v1 import ObjectMeta
-from kuber.v1_11.core_v1 import ObjectReference
-from kuber.v1_11.core_v1 import Probe
-from kuber.v1_11.core_v1 import ResourceRequirements
-from kuber.v1_11.core_v1 import SecurityContext
-from kuber.v1_11.meta_v1 import Status
-from kuber.v1_11.meta_v1 import StatusDetails
-from kuber.v1_11.core_v1 import VolumeDevice
-from kuber.v1_11.core_v1 import VolumeMount
+from kuber.v1_19.core_v1 import Container
+from kuber.v1_19.core_v1 import ContainerPort
+from kuber.v1_19.core_v1 import EnvFromSource
+from kuber.v1_19.core_v1 import EnvVar
+from kuber.v1_19.batch_v1 import JobSpec
+from kuber.v1_19.core_v1 import Lifecycle
+from kuber.v1_19.meta_v1 import ListMeta
+from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber.v1_19.core_v1 import ObjectReference
+from kuber.v1_19.core_v1 import Probe
+from kuber.v1_19.core_v1 import ResourceRequirements
+from kuber.v1_19.core_v1 import SecurityContext
+from kuber.v1_19.meta_v1 import Status
+from kuber.v1_19.meta_v1 import StatusDetails
+from kuber.v1_19.core_v1 import VolumeDevice
+from kuber.v1_19.core_v1 import VolumeMount
 
 
 class CronJob(_kuber_definitions.Resource):
@@ -58,8 +58,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self) -> 'ObjectMeta':
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -67,8 +67,8 @@ class CronJob(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union['ObjectMeta', dict]):
         """
         Standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
@@ -79,8 +79,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('spec')
 
@@ -89,8 +89,8 @@ class CronJob(_kuber_definitions.Resource):
         """
         Specification of the desired behavior of a cron job,
         including the schedule. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = CronJobSpec().from_dict(value)
@@ -100,8 +100,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self) -> 'CronJobStatus':
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('status')
 
@@ -109,8 +109,8 @@ class CronJob(_kuber_definitions.Resource):
     def status(self, value: typing.Union['CronJobStatus', dict]):
         """
         Current status of a cron job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = CronJobStatus().from_dict(value)
@@ -131,6 +131,7 @@ class CronJob(_kuber_definitions.Resource):
         readiness_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         resources: 'ResourceRequirements' = _kuber_definitions.UNCHANGED_VALUE,
         security_context: 'SecurityContext' = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         stdin: bool = _kuber_definitions.UNCHANGED_VALUE,
         stdin_once: bool = _kuber_definitions.UNCHANGED_VALUE,
         termination_message_path: str = _kuber_definitions.UNCHANGED_VALUE,
@@ -155,6 +156,7 @@ class CronJob(_kuber_definitions.Resource):
             'readiness_probe': readiness_probe,
             'resources': resources,
             'security_context': security_context,
+            'startup_probe': startup_probe,
             'stdin': stdin,
             'stdin_once': stdin_once,
             'termination_message_path': termination_message_path,
@@ -164,7 +166,7 @@ class CronJob(_kuber_definitions.Resource):
             'volume_mounts': volume_mounts,
             'working_dir': working_dir,
         }
-        self.spec.jobTemplate.spec.template.spec.containers.append(Container(**{
+        self.spec.job_template.spec.template.spec.containers.append(Container(**{
             k: v
             for k, v in values.items()
             if v != _kuber_definitions.UNCHANGED_VALUE
@@ -177,14 +179,14 @@ class CronJob(_kuber_definitions.Resource):
         container definition exists. Return None if no container definition
         by that name exists.
         """
-        return next((c for c in self.spec.jobTemplate.spec.template.spec.containers if c.name == name), None)
+        return next((c for c in self.spec.job_template.spec.template.spec.containers if c.name == name), None)
 
     def get_containers(self) -> typing.List['Container']:
         """
         Returns the list of containers stored in this resource if any such
         containers exist.
         """
-        return self.spec.jobTemplate.spec.template.spec.containers
+        return self.spec.job_template.spec.template.spec.containers
 
     def create_resource(
             self,
@@ -416,8 +418,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self) -> 'ListMeta':
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -425,8 +427,8 @@ class CronJobList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union['ListMeta', dict]):
         """
         Standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ListMeta().from_dict(value)
@@ -637,6 +639,7 @@ class CronJobSpec(_kuber_definitions.Definition):
         readiness_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         resources: 'ResourceRequirements' = _kuber_definitions.UNCHANGED_VALUE,
         security_context: 'SecurityContext' = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         stdin: bool = _kuber_definitions.UNCHANGED_VALUE,
         stdin_once: bool = _kuber_definitions.UNCHANGED_VALUE,
         termination_message_path: str = _kuber_definitions.UNCHANGED_VALUE,
@@ -661,6 +664,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             'readiness_probe': readiness_probe,
             'resources': resources,
             'security_context': security_context,
+            'startup_probe': startup_probe,
             'stdin': stdin,
             'stdin_once': stdin_once,
             'termination_message_path': termination_message_path,
@@ -670,7 +674,7 @@ class CronJobSpec(_kuber_definitions.Definition):
             'volume_mounts': volume_mounts,
             'working_dir': working_dir,
         }
-        self.jobTemplate.spec.template.spec.containers.append(Container(**{
+        self.job_template.spec.template.spec.containers.append(Container(**{
             k: v
             for k, v in values.items()
             if v != _kuber_definitions.UNCHANGED_VALUE
@@ -683,14 +687,14 @@ class CronJobSpec(_kuber_definitions.Definition):
         container definition exists. Return None if no container definition
         by that name exists.
         """
-        return next((c for c in self.jobTemplate.spec.template.spec.containers if c.name == name), None)
+        return next((c for c in self.job_template.spec.template.spec.containers if c.name == name), None)
 
     def get_containers(self) -> typing.List['Container']:
         """
         Returns the list of containers stored in this resource if any such
         containers exist.
         """
-        return self.jobTemplate.spec.template.spec.containers
+        return self.job_template.spec.template.spec.containers
 
     def __enter__(self) -> 'CronJobSpec':
         return self
@@ -809,8 +813,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -819,8 +823,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         """
         Standard object's metadata of the jobs created from this
         template. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
@@ -830,8 +834,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self) -> 'JobSpec':
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('spec')
 
@@ -839,8 +843,8 @@ class JobTemplateSpec(_kuber_definitions.Definition):
     def spec(self, value: typing.Union['JobSpec', dict]):
         """
         Specification of the desired behavior of the job. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = JobSpec().from_dict(value)
@@ -861,6 +865,7 @@ class JobTemplateSpec(_kuber_definitions.Definition):
         readiness_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         resources: 'ResourceRequirements' = _kuber_definitions.UNCHANGED_VALUE,
         security_context: 'SecurityContext' = _kuber_definitions.UNCHANGED_VALUE,
+        startup_probe: 'Probe' = _kuber_definitions.UNCHANGED_VALUE,
         stdin: bool = _kuber_definitions.UNCHANGED_VALUE,
         stdin_once: bool = _kuber_definitions.UNCHANGED_VALUE,
         termination_message_path: str = _kuber_definitions.UNCHANGED_VALUE,
@@ -885,6 +890,7 @@ class JobTemplateSpec(_kuber_definitions.Definition):
             'readiness_probe': readiness_probe,
             'resources': resources,
             'security_context': security_context,
+            'startup_probe': startup_probe,
             'stdin': stdin,
             'stdin_once': stdin_once,
             'termination_message_path': termination_message_path,
