@@ -5,10 +5,10 @@ from kubernetes import client
 from kuber import kube_api as _kube_api
 
 from kuber import definitions as _kuber_definitions
-from kuber.v1_17.meta_v1 import ListMeta
-from kuber.v1_17.meta_v1 import ObjectMeta
-from kuber.v1_17.meta_v1 import Status
-from kuber.v1_17.meta_v1 import StatusDetails
+from kuber.v1_19.meta_v1 import ListMeta
+from kuber.v1_19.meta_v1 import ObjectMeta
+from kuber.v1_19.meta_v1 import Status
+from kuber.v1_19.meta_v1 import StatusDetails
 
 
 class FlowDistinguisherMethod(_kuber_definitions.Definition):
@@ -96,8 +96,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def metadata(self) -> 'ObjectMeta':
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -105,8 +105,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union['ObjectMeta', dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
@@ -117,8 +117,8 @@ class FlowSchema(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('spec')
 
@@ -127,8 +127,8 @@ class FlowSchema(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = FlowSchemaSpec().from_dict(value)
@@ -138,8 +138,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def status(self) -> 'FlowSchemaStatus':
         """
         `status` is the current status of a FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('status')
 
@@ -147,8 +147,8 @@ class FlowSchema(_kuber_definitions.Resource):
     def status(self, value: typing.Union['FlowSchemaStatus', dict]):
         """
         `status` is the current status of a FlowSchema. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = FlowSchemaStatus().from_dict(value)
@@ -511,8 +511,8 @@ class FlowSchemaList(_kuber_definitions.Collection):
     def metadata(self) -> 'ListMeta':
         """
         `metadata` is the standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -520,8 +520,8 @@ class FlowSchemaList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union['ListMeta', dict]):
         """
         `metadata` is the standard list metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ListMeta().from_dict(value)
@@ -609,8 +609,8 @@ class FlowSchemaSpec(_kuber_definitions.Definition):
         that match a given request. The chosen FlowSchema is among
         those with the numerically lowest (which we take to be
         logically highest) MatchingPrecedence.  Each
-        MatchingPrecedence value must be non-negative. Note that if
-        the precedence is not specified or zero, it will be set to
+        MatchingPrecedence value must be ranged in [1,10000]. Note
+        that if the precedence is not specified, it will be set to
         1000 as default.
         """
         return self._properties.get('matchingPrecedence')
@@ -622,8 +622,8 @@ class FlowSchemaSpec(_kuber_definitions.Definition):
         that match a given request. The chosen FlowSchema is among
         those with the numerically lowest (which we take to be
         logically highest) MatchingPrecedence.  Each
-        MatchingPrecedence value must be non-negative. Note that if
-        the precedence is not specified or zero, it will be set to
+        MatchingPrecedence value must be ranged in [1,10000]. Note
+        that if the precedence is not specified, it will be set to
         1000 as default.
         """
         self._properties['matchingPrecedence'] = value
@@ -1213,8 +1213,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def metadata(self) -> 'ObjectMeta':
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -1222,8 +1222,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def metadata(self, value: typing.Union['ObjectMeta', dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ObjectMeta().from_dict(value)
@@ -1234,8 +1234,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         "request-priority". More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('spec')
 
@@ -1244,8 +1244,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
         """
         `spec` is the specification of the desired behavior of a
         "request-priority". More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = PriorityLevelConfigurationSpec().from_dict(value)
@@ -1255,8 +1255,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def status(self) -> 'PriorityLevelConfigurationStatus':
         """
         `status` is the current status of a "request-priority". More
-        info: https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        info: https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         return self._properties.get('status')
 
@@ -1264,8 +1264,8 @@ class PriorityLevelConfiguration(_kuber_definitions.Resource):
     def status(self, value: typing.Union['PriorityLevelConfigurationStatus', dict]):
         """
         `status` is the current status of a "request-priority". More
-        info: https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#spec-and-status
+        info: https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#spec-and-status
         """
         if isinstance(value, dict):
             value = PriorityLevelConfigurationStatus().from_dict(value)
@@ -1630,8 +1630,8 @@ class PriorityLevelConfigurationList(_kuber_definitions.Collection):
     def metadata(self) -> 'ListMeta':
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         return self._properties.get('metadata')
 
@@ -1639,8 +1639,8 @@ class PriorityLevelConfigurationList(_kuber_definitions.Collection):
     def metadata(self, value: typing.Union['ListMeta', dict]):
         """
         `metadata` is the standard object's metadata. More info:
-        https://git.k8s.io/community/contributors/devel/api-
-        conventions.md#metadata
+        https://git.k8s.io/community/contributors/devel/sig-
+        architecture/api-conventions.md#metadata
         """
         if isinstance(value, dict):
             value = ListMeta().from_dict(value)
